@@ -8,10 +8,10 @@ Please find a description of this package at:
 
 Author: Ilan Schnell
 """
-__version__ = '0.5.2'
-
 from ._bitarray import _bitarray, bits2bytes, _sysinfo
 
+__version__ = '0.7.0'
+
 
 def _tree_insert(tree, sym, ba):
     """
@@ -47,7 +47,7 @@ def _check_codedict(codedict):
 
 
 class bitarray(_bitarray):
-    """bitarray([initial][endian=string])
+    """bitarray([initial], [endian=string])
 
 Return a new bitarray object whose items are bits initialized from
 the optional initial, and endianness.
@@ -75,7 +75,7 @@ Allowed values are 'big' and 'little' (default is 'big').
 
 Note that setting the bit endianness only has an effect when accessing the
 machine representation of the bitarray, i.e. when using the methods: tofile,
-fromfile, tostring, fromstring, tobytes, frombytes."""
+fromfile, tobytes, frombytes."""
 
     def fromstring(self, string):
         """fromstring(string)
@@ -85,7 +85,7 @@ Deprecated since version 0.4.0, use ``frombytes()`` instead."""
         return self.frombytes(string.encode())
 
     def tostring(self):
-        """tostring()
+        """tostring() -> string
 
 Return the string representing (machine values) of the bitarray.
 When the length of the bitarray is not a multiple of 8, the few remaining
@@ -94,13 +94,21 @@ Deprecated since version 0.4.0, use ``tobytes()`` instead."""
         return self.tobytes().decode()
 
     def decode(self, codedict):
-        """decode(code)
+        """decode(code) -> list
 
 Given a prefix code (a dict mapping symbols to bitarrays),
 decode the content of the bitarray and return the list of symbols."""
         _check_codedict(codedict)
         return self._decode(_mk_tree(codedict))
 
+    def iterdecode(self, codedict):
+        """iterdecode(code) -> iterator
+
+Given a prefix code (a dict mapping symbols to bitarrays),
+decode the content of the bitarray and iterate over the symbols."""
+        _check_codedict(codedict)
+        return self._iterdecode(_mk_tree(codedict))
+
     def encode(self, codedict, iterable):
         """encode(code, iterable)
 
@@ -108,53 +116,13 @@ Given a prefix code (a dict mapping symbols to bitarrays),
 iterates over iterable object with symbols, and extends the bitarray
 with the corresponding bitarray for each symbols."""
         _check_codedict(codedict)
-        return self._encode(codedict, iterable)
-
-    def search(self, x, limit=-1):
-        """search(x[, limit])
-
-Given a bitarray x (or an object which can be converted to a bitarray),
-returns the start positions where x matches self as a list.
-The optional argument limits the number of search results to the integer
-specified.  By default, all search results are returned."""
-        return self._search(bitarray(x), limit)
-
-    def itersearch(self, x):
-        """itersearch(x)
-
-Given a bitarray x (or an object which can be converted to a bitarray),
-iterates over the start positions where x matches self."""
-        x = bitarray(x)
-        p = 0
-        while 1:
-            p = self._search_at(x, p)
-            if p is None:
-                return
-            yield p
-            p += 1
-
-    def __contains__(self, other):
-        """__contains__(x)
-
-Return True if bitarray contains x, False otherwise.
-If x is an integer (which includes booleans), it is determined
-whether or not the corresponding bit is contained in the bitarray.
-If x is an object which can be cast into a bitarray, such as e.g.
-the string '0110', a list, or a bitarray itself, a sequential search
-will be performed to determine return value."""
-        if isinstance(other, int):
-            try:
-                self.index(other)
-                return True
-            except ValueError:
-                return False
-        else:
-            return self._search_at(bitarray(other), 0) is not None
+        self._encode(codedict, iterable)
 
 
 def test(verbosity=1, repeat=1):
-    """test(verbosity=1, repeat=1)
+    """test(verbosity=1, repeat=1) -> TextTestResult
 
-Run self-test."""
+Run self-test, and return unittest.runner.TextTestResult object.
+"""
     from . import test_bitarray
     return test_bitarray.run(verbosity=verbosity, repeat=repeat)
