@@ -41,8 +41,10 @@ class Util(object):
 
     def randombitarrays(self):
         for n in list(range(25)) + [randint(1000, 2000)]:
-            yield bitarray([randint(0, 1) for d in range(n)],
-                           endian='big' if randint(0, 1) else 'little')
+            a = bitarray(endian='big' if randint(0, 1) else 'little')
+            a.frombytes(os.urandom(bits2bytes(n)))
+            del a[n:]
+            yield a
 
     def randomlists(self):
         for n in list(range(25)) + [randint(1000, 2000)]:
@@ -66,6 +68,11 @@ class Util(object):
         self.check_obj(a)
         self.check_obj(b)
 
+    def assertStopIteration(self, it):
+        if is_py3k:
+            return
+        self.assertRaises(StopIteration, it.next)
+
 
 def getIndicesEx(r, length):
     if not isinstance(r, slice):
@@ -245,6 +252,15 @@ class CreateObjectTests(unittest.TestCase, Util):
 
         self.assertRaises(ValueError, bitarray.__new__, bitarray, '01012100')
 
+    def test_rawbytes(self): # this representation is used for pickling
+        for s, r in [('\x00', ''), ('\x07\xff', '1'), ('\x03\xff', '11111'),
+                     ('\x01\x87\xda', '10000111' '1101101')]:
+            self.assertEqual(bitarray(to_bytes(s), endian='big'),
+                             bitarray(r))
+
+        for i in range(1, 8):
+            self.assertRaises(ValueError, bitarray.__new__,
+                              bitarray, to_bytes(chr(i)))
 
     def test_bitarray(self):
         for n in range(50):
@@ -473,6 +489,20 @@ class SliceTests(unittest.TestCase, Util):
         a[:] = True
         self.assertEqual(a, bitarray('11111111'))
 
+    def test_setslice_to_int(self):
+        a = bitarray('11111111')
+        a[::2] = 0
+        self.assertEqual(a, bitarray('01010101'))
+        a[4::] = 1
+        self.assertEqual(a, bitarray('01011111'))
+        a.__setitem__(slice(-2, None, None), 0)
+        self.assertEqual(a, bitarray('01011100'))
+
+        self.assertRaises(ValueError, a.__setitem__,
+                          slice(None, None, 2), 3)
+        self.assertRaises(ValueError, a.__setitem__,
+                          slice(None, 2, None), -1)
+
 
     def test_delitem1(self):
         a = bitarray('100110')
@@ -526,15 +556,18 @@ class MiscTests(unittest.TestCase, Util):
                 acc.append(b)
             self.assertEqual(acc, lst)
 
-    def test_iterable(self):
-        a = iter(bitarray('011'))
-        self.assertEqual(next(a), False)
-        self.assertEqual(next(a), True)
-        self.assertEqual(next(a), True)
-        if is_py3k:
-            self.assertRaises(StopIteration, a.__next__)
-        else:
-            self.assertRaises(StopIteration, a.next)
+    def test_iter1(self):
+        it = iter(bitarray('011'))
+        self.assertEqual(next(it), False)
+        self.assertEqual(next(it), True)
+        self.assertEqual(next(it), True)
+        self.assertStopIteration(it)
+
+    def test_iter2(self):
+        for a in self.randombitarrays():
+            aa = a.tolist()
+            self.assertEqual(list(a), aa)
+            self.assertEqual(list(iter(a)), aa)
 
     def test_assignment(self):
         a = bitarray('00110111001')
@@ -632,17 +665,21 @@ class MiscTests(unittest.TestCase, Util):
 
     def test_pickle(self):
         from pickle import loads, dumps
-        for a in self.randombitarrays():
-            b = loads(dumps(a))
-            self.assert_(b is not a)
-            self.assertEQUAL(a, b)
+        for v in range(3):
+            for a in self.randombitarrays():
+                b = loads(dumps(a, v))
+                self.assert_(b is not a)
+                self.assertEQUAL(a, b)
 
     def test_cPickle(self):
-        from pickle import loads, dumps
-        for a in self.randombitarrays():
-            b = loads(dumps(a))
-            self.assert_(b is not a)
-            self.assertEQUAL(a, b)
+        if is_py3k:
+            return
+        for v in range(3):
+            from cPickle import loads, dumps
+            for a in self.randombitarrays():
+                b = loads(dumps(a, v))
+                self.assert_(b is not a)
+                self.assertEQUAL(a, b)
 
     def test_overflow(self):
         from platform import architecture
@@ -939,6 +976,7 @@ class SequenceTests(unittest.TestCase, Util):
         a = bitarray()
         self.assert_(False not in a)
         self.assert_(True not in a)
+        self.assert_(bitarray() in a)
         a.append(True)
         self.assert_(True in a)
         self.assert_(False not in a)
@@ -948,6 +986,9 @@ class SequenceTests(unittest.TestCase, Util):
         a.append(True)
         self.assert_(0 in a)
         self.assert_(1 in a)
+        if not is_py3k:
+            self.assert_(long(0) in a)
+            self.assert_(long(1) in a)
 
     def test_contains2(self):
         a = bitarray()
@@ -955,8 +996,13 @@ class SequenceTests(unittest.TestCase, Util):
         a.append(1)
         self.assertEqual(a.__contains__(1), True)
         a = bitarray('0011')
-        self.assertEqual(a.__contains__('01'), True)
-        self.assertEqual(a.__contains__('10'), False)
+        self.assertEqual(a.__contains__(bitarray('01')), True)
+        self.assertEqual(a.__contains__(bitarray('10')), False)
+        self.assertRaises(TypeError, a.__contains__, 'asdf')
+        self.assertRaises(ValueError, a.__contains__, 2)
+        self.assertRaises(ValueError, a.__contains__, -1)
+        if not is_py3k:
+            self.assertRaises(ValueError, a.__contains__, long(2))
 
     def test_contains3(self):
         for n in range(2, 100):
@@ -976,13 +1022,9 @@ class SequenceTests(unittest.TestCase, Util):
 
     def test_contains4(self):
         a = bitarray('011010000001')
-        self.assert_('1' in a)
-        self.assert_('11' in a)
-        self.assert_('111' not in a)
-        self.assert_(bitarray('00') in a)
-        self.assert_([0, 0, 0, 1] in a)
-        self.assert_((0, 0, 0, 1, 1) not in a)
-        self.assert_((0, 0, 0, 0, 2) in a)
+        for s, r in [('', True), ('1', True), ('11', True), ('111', False),
+                     ('011', True), ('0001', True), ('00011', False)]:
+            self.assertEqual(bitarray(s) in a, r)
 
 
 tests.append(SequenceTests)
@@ -1036,7 +1078,21 @@ class ExtendTests(unittest.TestCase, Util):
                 self.assertEqual(c.tolist(), a + b)
                 self.check_obj(c)
 
-    def test_iterable(self):
+    def test_tuple(self):
+        a = bitarray()
+        a.extend((0, 1, 2, 0, 3))
+        self.assertEqual(a, bitarray('01101'))
+
+        for a in self.randomlists():
+            for b in self.randomlists():
+                c = bitarray(a)
+                idc = id(c)
+                c.extend(tuple(b))
+                self.assertEqual(id(c), idc)
+                self.assertEqual(c.tolist(), a + b)
+                self.check_obj(c)
+
+    def test_generator(self):
         def bar():
             for x in ('', '1', None, True, []):
                 yield x
@@ -1056,21 +1112,7 @@ class ExtendTests(unittest.TestCase, Util):
                 self.assertEqual(c.tolist(), a + b)
                 self.check_obj(c)
 
-    def test_tuple(self):
-        a = bitarray()
-        a.extend((0, 1, 2, 0, 3))
-        self.assertEqual(a, bitarray('01101'))
-
-        for a in self.randomlists():
-            for b in self.randomlists():
-                c = bitarray(a)
-                idc = id(c)
-                c.extend(tuple(b))
-                self.assertEqual(id(c), idc)
-                self.assertEqual(c.tolist(), a + b)
-                self.check_obj(c)
-
-    def test_iter(self):
+    def test_iterator1(self):
         a = bitarray()
         a.extend(iter([3, 9, 0, 1, -2]))
         self.assertEqual(a, bitarray('11011'))
@@ -1084,6 +1126,15 @@ class ExtendTests(unittest.TestCase, Util):
                 self.assertEqual(c.tolist(), a + b)
                 self.check_obj(c)
 
+    def test_iterator2(self):
+        try:
+            import itertools
+        except ImportError:
+            return
+        a = bitarray()
+        a.extend(itertools.repeat(True, 23))
+        self.assertEqual(a, bitarray(23 * '1'))
+
     def test_string01(self):
         a = bitarray()
         a.extend('0110111')
@@ -1134,12 +1185,13 @@ class MethodTests(unittest.TestCase, Util):
 
         for a in self.randombitarrays():
             aa = a.tolist()
-            item = bool(randint(0, 1))
-            pos = randint(-len(a), len(a))
-            a.insert(pos, item)
-            aa.insert(pos, item)
-            self.assertEqual(a.tolist(), aa)
-            self.check_obj(a)
+            for _ in range(50):
+                item = bool(randint(0, 1))
+                pos = randint(-len(a) - 2, len(a) + 2)
+                a.insert(pos, item)
+                aa.insert(pos, item)
+                self.assertEqual(a.tolist(), aa)
+                self.check_obj(a)
 
 
     def test_index(self):
@@ -1237,45 +1289,20 @@ class MethodTests(unittest.TestCase, Util):
 
         a = bitarray('10010101110011111001011')
         for limit in range(10):
-            self.assertEqual(a.search('011', limit),
+            self.assertEqual(a.search(bitarray('011'), limit),
                              [6, 11, 20][:limit])
-        # search is overlapping
-        self.assertEqual(a.search('111'), [7, 12, 13, 14])
-
-        self.assertRaises(ValueError, a.search, '')
-
-    def test_search_at(self):
-        a = bitarray('')
-        self.assertEqual(a._search_at(bitarray('0'), 0), None)
-        self.assertEqual(a._search_at(bitarray('1'), 0), None)
-
-        a = bitarray('1')
-        self.assertEqual(a._search_at(bitarray('0'), 0), None)
-        self.assertEqual(a._search_at(bitarray('1'), 0), 0)
-        self.assertEqual(a._search_at(bitarray('11'), 0), None)
-        self.assertRaises(ValueError, a._search_at, bitarray(), 0)
-        self.assertRaises(ValueError, a._search_at, bitarray('0'), -1)
-
-        a = bitarray('10011')
-        for s, start, res in [('0',  0, 1),    ('01',  0, 2),
-                              ('11', 1, 3),    ('000', 0, None),
-                              ('1',  0, 0),    ('1',   1, 3),
-                              ('1',  3, 3),    ('1',   4, 4),
-                              ('1',  5, None), ('11',  4, None),
-                              ('10011', 0, 0), ('100110', 0, None)]:
-            self.assertEqual(a._search_at(bitarray(s), start), res)
+        self.assertRaises(ValueError, a.search, bitarray())
+        self.assertRaises(TypeError, a.search, '010')
 
     def test_itersearch(self):
-        if is_py3k:
-            return
         a = bitarray('10011')
-        it = a.itersearch('1')
-        self.assertEqual(it.next(), 0)
-        self.assertEqual(it.next(), 3)
-        self.assertEqual(it.next(), 4)
-        self.assertRaises(StopIteration, it.next)
-        it = a.itersearch('')
-        self.assertRaises(ValueError, it.next)
+        self.assertRaises(ValueError, a.itersearch, bitarray())
+        self.assertRaises(TypeError, a.itersearch, '')
+        it = a.itersearch(bitarray('1'))
+        self.assertEqual(next(it), 0)
+        self.assertEqual(next(it), 3)
+        self.assertEqual(next(it), 4)
+        self.assertStopIteration(it)
 
     def test_search2(self):
         a = bitarray('10011')
@@ -1284,22 +1311,20 @@ class MethodTests(unittest.TestCase, Util):
                        ('000',   []),      ('1001', [0]),
                        ('011',   [2]),     ('0011', [1]),
                        ('10011', [0]),     ('100111', [])]:
-            self.assertEqual(a.search(s), res)
-            self.assertEqual([p for p in a.itersearch(s)], res)
             b = bitarray(s)
             self.assertEqual(a.search(b), res)
-            self.assertEqual(a.search(list(b)), res)
-            self.assertEqual(a.search(tuple(b)), res)
+            self.assertEqual([p for p in a.itersearch(b)], res)
 
     def test_search3(self):
         a = bitarray('10010101110011111001011')
         for s, res in [('011', [6, 11, 20]),
-                       ('111', [7, 12, 13, 14]),
+                       ('111', [7, 12, 13, 14]), # note the overlap
                        ('1011', [5, 19]),
                        ('100', [0, 9, 16])]:
-            self.assertEqual(a.search(s), res)
-            self.assertEqual(list(a.itersearch(s)), res)
-            self.assertEqual([p for p in a.itersearch(s)], res)
+            b = bitarray(s)
+            self.assertEqual(a.search(b), res)
+            self.assertEqual(list(a.itersearch(b)), res)
+            self.assertEqual([p for p in a.itersearch(b)], res)
 
 
     def test_fill(self):
@@ -1509,7 +1534,8 @@ class StringTests(unittest.TestCase, Util):
 
         b = a
         b.frombytes(to_bytes('BC'))
-        self.assertEQUAL(b, bitarray('01000001' '01000010' '01000011'))
+        self.assertEQUAL(b, bitarray('01000001' '01000010' '01000011',
+                                     endian='big'))
         self.assert_(b is a)
 
         for b in self.randombitarrays():
@@ -1617,19 +1643,31 @@ class FileTests(unittest.TestCase, Util):
         shutil.rmtree(self.tmpdir)
 
 
-    def test_cPickle(self):
+    def test_pickle(self):
         from pickle import load, dump
 
-        for a in self.randombitarrays():
-            fo = open(self.tmpfname, 'wb')
-            dump(a, fo)
-            fo.close()
+        for v in range(3):
+            for a in self.randombitarrays():
+                fo = open(self.tmpfname, 'wb')
+                dump(a, fo, v)
+                fo.close()
+                b = load(open(self.tmpfname, 'rb'))
+                self.assert_(b is not a)
+                self.assertEQUAL(a, b)
 
-            b = load(open(self.tmpfname, 'rb'))
-
-            self.assert_(b is not a)
-            self.assertEQUAL(a, b)
+    def test_cPickle(self):
+        if is_py3k:
+            return
+        from cPickle import load, dump
 
+        for v in range(3):
+            for a in self.randombitarrays():
+                fo = open(self.tmpfname, 'wb')
+                dump(a, fo, v)
+                fo.close()
+                b = load(open(self.tmpfname, 'rb'))
+                self.assert_(b is not a)
+                self.assertEQUAL(a, b)
 
     def test_shelve(self):
         import shelve, hashlib
@@ -1801,26 +1839,26 @@ tests.append(FileTests)
 
 # ---------------------------------------------------------------------------
 
-class PrefixCodeTests(unittest.TestCase):
+class PrefixCodeTests(unittest.TestCase, Util):
 
-    def test_encode_check_codedict(self):
+    def test_encode_errors(self):
         a = bitarray()
         self.assertRaises(TypeError, a.encode, 0, '')
         self.assertRaises(ValueError, a.encode, {}, '')
         self.assertRaises(TypeError, a.encode, {'a':42}, '')
-        self.assertRaises(ValueError, a.encode, {'a':bitarray()}, '')
+        self.assertRaises(ValueError, a.encode, {'a': bitarray()}, '')
         # 42 not iterable
-        self.assertRaises(TypeError, a.encode, {'a':bitarray('0')}, 42)
+        self.assertRaises(TypeError, a.encode, {'a': bitarray('0')}, 42)
         self.assertEqual(len(a), 0)
 
     def test_encode_string(self):
         a = bitarray()
-        d = {'a':bitarray('0')}
+        d = {'a': bitarray('0')}
         a.encode(d, '')
         self.assertEqual(a, bitarray())
         a.encode(d, 'a')
         self.assertEqual(a, bitarray('0'))
-        self.assertEqual(d, {'a':bitarray('0')})
+        self.assertEqual(d, {'a': bitarray('0')})
 
     def test_encode_list(self):
         a = bitarray()
@@ -1829,11 +1867,11 @@ class PrefixCodeTests(unittest.TestCase):
         self.assertEqual(a, bitarray())
         a.encode(d, ['a'])
         self.assertEqual(a, bitarray('0'))
-        self.assertEqual(d, {'a':bitarray('0')})
+        self.assertEqual(d, {'a': bitarray('0')})
 
     def test_encode_iter(self):
         a = bitarray()
-        d = {'a':bitarray('0'), 'b':bitarray('1')}
+        d = {'a': bitarray('0'), 'b': bitarray('1')}
         a.encode(d, iter('abba'))
         self.assertEqual(a, bitarray('0110'))
 
@@ -1843,20 +1881,20 @@ class PrefixCodeTests(unittest.TestCase):
 
         a.encode(d, foo())
         self.assertEqual(a, bitarray('0110110011'))
-        self.assertEqual(d, {'a':bitarray('0'), 'b':bitarray('1')})
+        self.assertEqual(d, {'a': bitarray('0'), 'b': bitarray('1')})
 
     def test_encode(self):
-        d = {'I':bitarray('1'),
-             'l':bitarray('01'),
-             'a':bitarray('001'),
-             'n':bitarray('000')}
+        d = {'I': bitarray('1'),
+             'l': bitarray('01'),
+             'a': bitarray('001'),
+             'n': bitarray('000')}
         a = bitarray()
         a.encode(d, 'Ilan')
         self.assertEqual(a, bitarray('101001000'))
         a.encode(d, 'a')
         self.assertEqual(a, bitarray('101001000001'))
-        self.assertEqual(d, {'I':bitarray('1'), 'l':bitarray('01'),
-                             'a':bitarray('001'), 'n':bitarray('000')})
+        self.assertEqual(d, {'I': bitarray('1'), 'l': bitarray('01'),
+                             'a': bitarray('001'), 'n': bitarray('000')})
         self.assertRaises(ValueError, a.encode, d, 'arvin')
 
 
@@ -1869,56 +1907,97 @@ class PrefixCodeTests(unittest.TestCase):
         self.assertRaises(ValueError, a.decode, {'a':bitarray()})
 
     def test_decode_simple(self):
-        d = {'I':bitarray('1'),
-             'l':bitarray('01'),
-             'a':bitarray('001'),
-             'n':bitarray('000')}
+        d = {'I': bitarray('1'),
+             'l': bitarray('01'),
+             'a': bitarray('001'),
+             'n': bitarray('000')}
+        dcopy = dict(d)
         a = bitarray('101001000')
         self.assertEqual(a.decode(d), ['I', 'l', 'a', 'n'])
-        self.assertEqual(d, {'I':bitarray('1'), 'l':bitarray('01'),
-                             'a':bitarray('001'), 'n':bitarray('000')})
+        self.assertEqual(d, dcopy)
+        self.assertEqual(a, bitarray('101001000'))
+
+    def test_iterdecode_simple(self):
+        d = {'I': bitarray('1'),
+             'l': bitarray('01'),
+             'a': bitarray('001'),
+             'n': bitarray('000')}
+        dcopy = dict(d)
+        a = bitarray('101001000')
+        self.assertEqual(list(a.iterdecode(d)), ['I', 'l', 'a', 'n'])
+        self.assertEqual(d, dcopy)
         self.assertEqual(a, bitarray('101001000'))
 
     def test_decode_empty(self):
-        d = {'a':bitarray('1')}
+        d = {'a': bitarray('1')}
         a = bitarray()
         self.assertEqual(a.decode(d), [])
-        self.assertEqual(d, {'a':bitarray('1')})
+        self.assertEqual(d, {'a': bitarray('1')})
+        # test decode iterator
+        self.assertEqual(list(a.iterdecode(d)), [])
+        self.assertEqual(d, {'a': bitarray('1')})
+        self.assertEqual(len(a), 0)
 
     def test_decode_buggybitarray(self):
-        d = {'a':bitarray('0')}
+        d = {'a': bitarray('0')}
         a = bitarray('1')
         self.assertRaises(ValueError, a.decode, d)
         self.assertEqual(a, bitarray('1'))
-        self.assertEqual(d, {'a':bitarray('0')})
+        self.assertEqual(d, {'a': bitarray('0')})
+
+    def test_iterdecode_buggybitarray(self):
+        d = {'a': bitarray('0')}
+        a = bitarray('1')
+        it = a.iterdecode(d)
+        if not is_py3k:
+            self.assertRaises(ValueError, it.next)
+        self.assertEqual(a, bitarray('1'))
+        self.assertEqual(d, {'a': bitarray('0')})
 
     def test_decode_buggybitarray2(self):
-        d = {'a':bitarray('00'), 'b':bitarray('01')}
+        d = {'a': bitarray('00'), 'b': bitarray('01')}
         a = bitarray('1')
         self.assertRaises(ValueError, a.decode, d)
         self.assertEqual(a, bitarray('1'))
 
+    def test_iterdecode_buggybitarray2(self):
+        d = {'a': bitarray('00'), 'b': bitarray('01')}
+        a = bitarray('1')
+        it = a.iterdecode(d)
+        if not is_py3k:
+            self.assertRaises(ValueError, it.next)
+        self.assertEqual(a, bitarray('1'))
+
     def test_decode_ambiguous_code(self):
-        d = {'a':bitarray('0'), 'b':bitarray('0'), 'c':bitarray('1')}
+        d = {'a': bitarray('0'), 'b': bitarray('0'), 'c': bitarray('1')}
         a = bitarray()
         self.assertRaises(ValueError, a.decode, d)
+        self.assertRaises(ValueError, a.iterdecode, d)
 
     def test_decode_ambiguous2(self):
-        d = {'a':bitarray('01'), 'b':bitarray('01'), 'c':bitarray('1')}
+        d = {'a': bitarray('01'), 'b': bitarray('01'), 'c': bitarray('1')}
         a = bitarray()
         self.assertRaises(ValueError, a.decode, d)
-
+        self.assertRaises(ValueError, a.iterdecode, d)
 
     def test_miscitems(self):
-        d = {None :bitarray('00'),
-             0    :bitarray('110'),
-             1    :bitarray('111'),
-             ''   :bitarray('010'),
-             2    :bitarray('011')}
+        d = {None : bitarray('00'),
+             0    : bitarray('110'),
+             1    : bitarray('111'),
+             ''   : bitarray('010'),
+             2    : bitarray('011')}
         a = bitarray()
         a.encode(d, [None, 0, 1, '', 2])
         self.assertEqual(a, bitarray('00110111010011'))
         self.assertEqual(a.decode(d), [None, 0, 1, '', 2])
+        # iterator
+        it = a.iterdecode(d)
+        self.assertEqual(next(it), None)
+        self.assertEqual(next(it), 0)
+        self.assertEqual(next(it), 1)
+        self.assertEqual(next(it), '')
+        self.assertEqual(next(it), 2)
+        self.assertStopIteration(it)
 
     def test_real_example(self):
         code = {' '  : bitarray('001'),
@@ -1950,16 +2029,54 @@ class PrefixCodeTests(unittest.TestCase):
                 'y'  : bitarray('101010'),
                 'z'  : bitarray('00011011110')}
         a = bitarray()
-        a.encode(code, 'the quick brown fox jumps over the lazy dog.')
+        message = 'the quick brown fox jumps over the lazy dog.'
+        a.encode(code, message)
         self.assertEqual(a, bitarray('01000000011100100001001101000100101100'
           '00110001101000100011001101100001111110010010101001000000010001100'
           '10111101111000100000111101001110000110000111100111110100101000000'
           '0111001011100110000110111101010100010101110001010000101010'))
-        self.assertEqual(''.join(a.decode(code)),
-                         'the quick brown fox jumps over the lazy dog.')
+        self.assertEqual(''.join(a.decode(code)), message)
+        self.assertEqual(''.join(a.iterdecode(code)), message)
+
 
 tests.append(PrefixCodeTests)
 
+# -------------- Buffer Interface (Python 2.7 only for now) ----------------
+
+class BufferInterfaceTests(unittest.TestCase):
+
+    def test_read1(self):
+        a = bitarray('01000001' '01000010' '01000011', endian='big')
+        v = memoryview(a)
+        self.assertEqual(len(v), 3)
+        self.assertEqual(v[0], 'A')
+        self.assertEqual(v[:].tobytes(), 'ABC')
+        a[13] = 1
+        self.assertEqual(v[:].tobytes(), 'AFC')
+
+    def test_read2(self):
+        a = bitarray([randint(0, 1) for d in range(8000)])
+        v = memoryview(a)
+        self.assertEqual(len(v), 1000)
+        b = a[345 * 8 : 657 * 8]
+        self.assertEqual(v[345:657].tobytes(), b.tobytes())
+        self.assertEqual(v[:].tobytes(), a.tobytes())
+
+    def test_write(self):
+        a = bitarray(800000)
+        a.setall(0)
+        v = memoryview(a)
+        self.assertFalse(v.readonly)
+        v[50000] = '\xff'
+        self.assertEqual(a[399999:400009], bitarray('0111111110'))
+        a[400003] = 0
+        self.assertEqual(a[399999:400009], bitarray('0111011110'))
+        v[30001:30004] = 'ABC'
+        self.assertEqual(a[240000:240040].tobytes(), '\x00ABC\x00')
+
+if sys.version_info[:2] == (2, 7):
+    tests.append(BufferInterfaceTests)
+
 # ---------------------------------------------------------------------------
 
 def run(verbosity=1, repeat=1):
